@@ -124,7 +124,7 @@ zgmp_urandomb_ui zgmp_urandomm_ui
     );
 
     @Math::GMPz::EXPORT_OK = (@untagged, @tagged);
-    our $VERSION = '0.64';
+    our $VERSION = '0.66';
     #$VERSION = eval $VERSION;
 
     Math::GMPz->DynaLoader::bootstrap($VERSION);
@@ -202,11 +202,28 @@ sub new {
 
     }
 
+    if($type == _MATH_GMPq_T) {
+      if(@_ ) {die "Too many arguments supplied to new() - expected only one"}
+      my $ret = Rmpz_init();
+      Rmpz_set_q($ret, $arg1);
+      return $ret;
+    }
+
     if($type == _MATH_GMPz_T || $type == _MATH_GMP_T) { # Math::GMPz or Math::GMP object
       if(@_) {die "Too many arguments supplied to new() - expected only one"}
       return Rmpz_init_set($arg1);
     }
 
+    if($type == _MATH_MPFR_T) {
+      if(@_ ) {die "Too many arguments supplied to new() - expected only one"}
+      die "Cannot assign Inf or NaN to a Math::GMPz object"
+        if(Math::MPFR::Rmpfr_nan_p($arg1) || Math::MPFR::Rmpfr_inf_p($arg1));
+      my $ret = Rmpz_init();
+      Math::MPFR::Rmpfr_get_z($ret, $arg1, 1); # truncate Math::MPFR object $arg1 to an
+                                               # integer value, and copy that value to $ret.
+      return $ret;
+    }
+
     if($type == -1) { # Math::BigInt
       if(@_) {die "Too many arguments supplied to new() - expected only one"}
       return _new_from_MBI($arg1);
@@ -639,9 +656,63 @@ sub overload_pow_eq {
     my $z = Math::GMPz->new($_[1]);
     return _overload_pow_eq($_[0], $z, 0);
   }
+  if($itsa == 5) { # Math::MPFR object
+    my $mpfr_obj = Math::MPFR::Rmpfr_init2(Rmpz_sizeinbase($_[0], 2));
+    Math::MPFR::Rmpfr_set_z($mpfr_obj, $_[0], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    my $ret = Math::MPFR::Rmpfr_init2(Math::MPFR::Rmpfr_get_prec($_[1]));
+    Math::MPFR::Rmpfr_pow($ret, $mpfr_obj, $_[1], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    return $ret;
+  }
   return _overload_pow_eq(@_);
 }
 
+sub overload_add_eq {
+  if(_itsa($_[1]) == 5) { # Math::MPFR object
+    my $ret = Math::MPFR::Rmpfr_init2(Math::MPFR::Rmpfr_get_prec($_[1]));
+    Math::MPFR::Rmpfr_add_z($ret, $_[1], $_[0], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    return $ret;
+  }
+  return _overload_add_eq(@_);
+}
+
+sub overload_mul_eq {
+  if(_itsa($_[1]) == 5) { # Math::MPFR object
+    my $ret = Math::MPFR::Rmpfr_init2(Math::MPFR::Rmpfr_get_prec($_[1]));
+    Math::MPFR::Rmpfr_mul_z($ret, $_[1], $_[0], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    return $ret;
+  }
+  return _overload_mul_eq(@_);
+}
+
+sub overload_sub_eq {
+  if(_itsa($_[1]) == 5) { # Math::MPFR object
+    my $ret = Math::MPFR::Rmpfr_init2(Math::MPFR::Rmpfr_get_prec($_[1]));
+    Math::MPFR::Rmpfr_z_sub($ret, $_[0], $_[1], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    return $ret;
+  }
+  return _overload_sub_eq(@_);
+}
+
+sub overload_div_eq {
+  if(_itsa($_[1]) == 5) { # Math::MPFR object
+    my $ret = Math::MPFR::Rmpfr_init2(Math::MPFR::Rmpfr_get_prec($_[1]));
+    Math::MPFR::Rmpfr_z_div($ret, $_[0], $_[1], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    return $ret;
+  }
+  return _overload_div_eq(@_);
+}
+
+sub overload_mod_eq {
+  if(_itsa($_[1]) == 5) { # Math::MPFR object
+    my $mpfr_obj = Math::MPFR::Rmpfr_init2(Rmpz_sizeinbase($_[0], 2));
+    Math::MPFR::Rmpfr_set_z($mpfr_obj, $_[0], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    my $ret = Math::MPFR::Rmpfr_init2(Math::MPFR::Rmpfr_get_prec($_[1]));
+    Math::MPFR::Rmpfr_fmod($ret, $mpfr_obj, $_[1], Math::MPFR::Rmpfr_get_default_rounding_mode());
+    return $ret;
+  }
+  return _overload_mod_eq(@_);
+}
+
 sub __GNU_MP_VERSION            () {return ___GNU_MP_VERSION()}
 sub __GNU_MP_VERSION_MINOR      () {return ___GNU_MP_VERSION_MINOR()}
 sub __GNU_MP_VERSION_PATCHLEVEL () {return ___GNU_MP_VERSION_PATCHLEVEL()}
